boundedur-package: boundedur: Unit Root Tests for Bounded Time Series

boundedur-packageR Documentation

boundedur: Unit Root Tests for Bounded Time Series

Description

The boundedur package implements unit root tests for bounded time series following the methodology of Cavaliere and Xu (2014). Standard unit root tests (ADF, Phillips-Perron) have non-standard limiting distributions when the time series is constrained to lie within bounds. This package provides modified tests with p-values computed via Monte Carlo simulation of bounded Brownian motion.

Main Functions

boundedur

Main function to perform bounded unit root tests

simulate_bounded_bm

Simulate bounded Brownian motion

select_lag_maic

Select optimal lag using MAIC criterion

Available Tests

  • ADF-alpha: Augmented Dickey-Fuller normalized bias test

  • ADF-t: Augmented Dickey-Fuller t-statistic test

  • MZ-alpha: Modified Phillips-Perron normalized bias test

  • MZ-t: Modified Phillips-Perron t-statistic test

  • MSB: Modified Sargan-Bhargava test

Author(s)

Maintainer:

Other contributors:

  • Giuseppe Cavaliere (Original methodology) [contributor]

  • Fang Xu (Original methodology) [contributor]

References

Cavaliere, G., & Xu, F. (2014). Testing for unit roots in bounded time series. Journal of Econometrics, 178(2), 259-272. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.jeconom.2013.08.012")}

Ng, S., & Perron, P. (2001). Lag length selection and the construction of unit root tests with good size and power. Econometrica, 69(6), 1519-1554. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1111/1468-0262.00256")}


boundedur documentation built on March 16, 2026, 5:08 p.m.